from django import forms
from django.contrib.auth.models import Group
from django.utils.translation import ugettext as _


class ProjectForm(forms.Form):
    """
    Form for working with Project instances.
    ModelForm does not cut it for me :/
    """

    name = forms.CharField(
        label=_(u"Projet name"),
        help_text=_(u"Any name of your liking, can be fixed later if you change your mind"),
        required=True,
        max_length=100)

    group = forms.ModelChoiceField(
        label=_(u"Group owner"),
        help_text=_(u"Members of the selected group will co-own this project"),
        empty_label=_("None, I'll be the owner"),
        required=False,
        queryset=Group.objects.all())

    is_public = forms.BooleanField(
        label=_(u"Project is public"),
        help_text=_(u"If selected then this project will be visible to anyone."
                    u" Otherwise only owners can see the project"),
        required=False)

    is_aggregate = forms.BooleanField(
        label=_(u"Project is an aggregation (distribution)"),
        help_text=_(u"When selected the project will be treated like a"
                    u" distribution. Some UI elements are optimized for that case"
                    u" and behave differently."),
        required=False)

    def restrict_group_selection_for_user(self, user):
        assert user is not None
        self.fields['group'].queryset = user.groups.all()
