# Copyright (C) 2010, 2011 Linaro Limited
#
# Author: Zygmunt Krynicki <zygmunt.krynicki@linaro.org>
#
# This file is part of LAVA Server.
#
# LAVA Server is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License version 3
# as published by the Free Software Foundation
#
# LAVA Server is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with LAVA Server.  If not, see <http://www.gnu.org/licenses/>.

"""
Headless model application experiment
"""

from django.db import models
from django.utils.translation import ugettext as _

from django_restricted_resource.models  import RestrictedResource


class Project(RestrictedResource):
    """
    Project is a container of everything else. Projects are restricted
    resources and thus belong to a particular user or group and have a "public"
    flag.
    """

    name = models.CharField(
        null=False,
        blank=False,
        max_length=100,
        verbose_name=_(u"Name"),
        help_text=_(u"Arbitrary text, up to 100 characters"
                    u", can be changed later"))

    is_aggregate = models.BooleanField(
        blank=True,
        null=False,
        verbose_name=_("Aggregate"),
        help_text=_(u"When selected the project will be treated like a"
                    u" distribution. Some UI elements are optimized for that case"
                    u" and behave differently."))

    def __unicode__(self):
        return self.name

    @models.permalink
    def get_absolute_url(self):
        return ('lava_data_store.views.project_detail', [self.pk])
