from django.contrib.auth.decorators import login_required
from django.http import HttpResponse, HttpResponseRedirect
from django.shortcuts import get_object_or_404
from django.template import RequestContext, loader
from django.utils.translation import ugettext as _
from django.views.generic.list_detail import object_list, object_detail

from lava_data_store.models import Project
from lava_data_store.forms import ProjectForm


def project_list(request):
    return object_list(
        request,
        queryset=Project.objects.accessible_by_principal(request.user),
        template_name="lava_data_store/project_list.html",
        template_object_name="project")


def project_detail(request, pk):
    return object_detail(
        request,
        object_id=pk,
        queryset=Project.objects.accessible_by_principal(request.user),
        template_name="lava_data_store/project_detail.html",
        template_object_name="project")


@login_required
def project_create(request):
    if request.method == 'POST':
        form = ProjectForm(request.POST, request.FILES)
        form.restrict_group_selection_for_user(request.user)
        if form.is_valid():
            print form.cleaned_data
            project = Project.objects.create(
                owner=form.cleaned_data['group'] or request.user,
                is_public=form.cleaned_data['is_public'],
                name=form.cleaned_data['name'],
                is_aggregate=form.cleaned_data['is_aggregate'])
            return HttpResponseRedirect(project.get_absolute_url())
    else:
        form = ProjectForm()
    template_name = "lava_data_store/project_form.html"
    t = loader.get_template(template_name)
    c = RequestContext(request, {
        'form': form,
        'submit_text': _(u"Create project")
    })
    return HttpResponse(t.render(c))


@login_required
def project_update(request, pk):
    project = get_object_or_404(
        Project.objects.accessible_by_principal(request.user), 
        pk=pk)
    if request.method == 'POST':
        form = ProjectForm(request.POST, request.FILES)
        form.restrict_group_selection_for_user(request.user)
        if form.is_valid():
            project.owner = form.cleaned_data['group'] or request.user
            project.is_public = form.cleaned_data['is_public']
            project.name = form.cleaned_data['name']
            project.is_aggregate = form.cleaned_data['is_aggregate']
            project.save()
            return HttpResponseRedirect(project.get_absolute_url())
    else:
        form = ProjectForm(initial=dict(
            group=project.group,
            is_public=project.is_public,
            name=project.name,
            is_aggregate=project.is_aggregate))
    template_name = "lava_data_store/project_form.html"
    t = loader.get_template(template_name)
    c = RequestContext(request, {
        'form': form,
        'submit_text': _(u"Update project")
    })
    return HttpResponse(t.render(c))




